# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from kaistack.clients.grpcclient import pipelinecomponentapis_pb2 as pipelinecomponentapis__pb2


class PipelineComponentServiceStub(object):
    """Missing associated documentation comment in .proto file"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListComponents = channel.unary_unary(
                '/codegen.PipelineComponentService/ListComponents',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.ListComponentsResponse.FromString,
                )
        self.GetComponents = channel.unary_unary(
                '/codegen.PipelineComponentService/GetComponents',
                request_serializer=pipelinecomponentapis__pb2.GetComponentRequest.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.GetComponentResponse.FromString,
                )
        self.CreateComponent = channel.unary_unary(
                '/codegen.PipelineComponentService/CreateComponent',
                request_serializer=pipelinecomponentapis__pb2.CreateComponentRequest.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.CreateComponentResponse.FromString,
                )
        self.UpdateComponent = channel.unary_unary(
                '/codegen.PipelineComponentService/UpdateComponent',
                request_serializer=pipelinecomponentapis__pb2.UpdateComponentRequest.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.UpdateComponentResponse.FromString,
                )
        self.ListComponentVersions = channel.unary_unary(
                '/codegen.PipelineComponentService/ListComponentVersions',
                request_serializer=pipelinecomponentapis__pb2.ListComponentVersionsRequest.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.ListComponentVersionsResponse.FromString,
                )
        self.DeleteComponent = channel.unary_unary(
                '/codegen.PipelineComponentService/DeleteComponent',
                request_serializer=pipelinecomponentapis__pb2.DeleteComponentRequest.SerializeToString,
                response_deserializer=pipelinecomponentapis__pb2.DeleteComponentResponse.FromString,
                )


class PipelineComponentServiceServicer(object):
    """Missing associated documentation comment in .proto file"""

    def ListComponents(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetComponents(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateComponent(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateComponent(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListComponentVersions(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteComponent(self, request, context):
        """Missing associated documentation comment in .proto file"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PipelineComponentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListComponents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListComponents,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=pipelinecomponentapis__pb2.ListComponentsResponse.SerializeToString,
            ),
            'GetComponents': grpc.unary_unary_rpc_method_handler(
                    servicer.GetComponents,
                    request_deserializer=pipelinecomponentapis__pb2.GetComponentRequest.FromString,
                    response_serializer=pipelinecomponentapis__pb2.GetComponentResponse.SerializeToString,
            ),
            'CreateComponent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateComponent,
                    request_deserializer=pipelinecomponentapis__pb2.CreateComponentRequest.FromString,
                    response_serializer=pipelinecomponentapis__pb2.CreateComponentResponse.SerializeToString,
            ),
            'UpdateComponent': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateComponent,
                    request_deserializer=pipelinecomponentapis__pb2.UpdateComponentRequest.FromString,
                    response_serializer=pipelinecomponentapis__pb2.UpdateComponentResponse.SerializeToString,
            ),
            'ListComponentVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListComponentVersions,
                    request_deserializer=pipelinecomponentapis__pb2.ListComponentVersionsRequest.FromString,
                    response_serializer=pipelinecomponentapis__pb2.ListComponentVersionsResponse.SerializeToString,
            ),
            'DeleteComponent': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteComponent,
                    request_deserializer=pipelinecomponentapis__pb2.DeleteComponentRequest.FromString,
                    response_serializer=pipelinecomponentapis__pb2.DeleteComponentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'codegen.PipelineComponentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PipelineComponentService(object):
    """Missing associated documentation comment in .proto file"""

    @staticmethod
    def ListComponents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/ListComponents',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            pipelinecomponentapis__pb2.ListComponentsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetComponents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/GetComponents',
            pipelinecomponentapis__pb2.GetComponentRequest.SerializeToString,
            pipelinecomponentapis__pb2.GetComponentResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateComponent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/CreateComponent',
            pipelinecomponentapis__pb2.CreateComponentRequest.SerializeToString,
            pipelinecomponentapis__pb2.CreateComponentResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateComponent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/UpdateComponent',
            pipelinecomponentapis__pb2.UpdateComponentRequest.SerializeToString,
            pipelinecomponentapis__pb2.UpdateComponentResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListComponentVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/ListComponentVersions',
            pipelinecomponentapis__pb2.ListComponentVersionsRequest.SerializeToString,
            pipelinecomponentapis__pb2.ListComponentVersionsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteComponent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/codegen.PipelineComponentService/DeleteComponent',
            pipelinecomponentapis__pb2.DeleteComponentRequest.SerializeToString,
            pipelinecomponentapis__pb2.DeleteComponentResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



import click
import yaml

import kaistack
from kaistack.components.component_store import ComponentStore
from kaistack.components.kubeflow_converter import create_workflow_template_from_component_spec


def convert_component(path):
    wf = create_workflow_template_from_component_spec(path)
    return wf


@click.command("upload-component")
@click.option("--path", required=True, help="The input file path")
@click.option("--service", help="The service endpoint")
@click.option("--name", help="The component name. If not set, it will by default use the name in the yaml")
@click.option("--convert", is_flag=True, default=False, help='If configured, will convert from kfp component spec. If not set, the progam will detect')
def upload_component(path, name, service, convert):
    spec = ''
    if not convert:
        # Sniff the file
        with open(path, 'r') as f:
            spec = f.read()
            convert = not spec.startswith("apiVersion")
    if convert:
        click.echo("Convert the spec")
        spec = yaml.dump(convert_component(path))

    apibase = service+"/kaistackapiserver"
    click.echo("Initialize component store. service:[{0}] api_base [{1}]".format(service, apibase))
    store = ComponentStore(service, apibase)
    try:
        store.create_component(spec, name)
        click.echo("Create component successfully")
    except kaistack.clients.openapi_clients.pipelinecomponents.exceptions.ApiException:
        store.update_component(spec, name)
        click.echo("Update component successfully")



import json
import os

import click

_CONTEXT_ENV_NAME = "KAISTACK_CONTEXT_PATH"
_DEFAULT_CONTEXT_PATH = "~/.kaistack/context.json"


def get_file_path():
    path = os.environ.get(_CONTEXT_ENV_NAME)
    if path is None:
        path = _DEFAULT_CONTEXT_PATH
    return path


def load_context():
    context_file = get_file_path()
    context_file = os.path.expanduser(context_file) if context_file.startswith("~") else context_file
    with open(context_file, 'r') as f:
        config = f.read()
        return json.loads(config)


@click.command(name="get-context")
def get_context():
    context = load_context()
    click.echo(context)


@click.command(name="set-context")
def set_context():
    click.echo("set config")



import os
import unittest

from kfp import dsl

from kaistack.components.kubeflow_converter import component_to_template, containerOp_to_template

COMPONENT_SPEC_FILENAME = os.path.join(os.path.dirname(__file__), 'kfp_component.yaml')


class KubeflowConverterTest(unittest.TestCase):
    def test_component_to_workflow_template(self):
        template = component_to_template(COMPONENT_SPEC_FILENAME)
        self.assertEqual('irxxo3tmn5qwiidgojxw2ichinjq', template['name'])  # Name has a space. It is encoded
        self.assertEqual(1, len(template['inputs']['parameters']))
        self.assertEqual('GCS-path', template['inputs']['parameters'][0]['name'])
        self.assertEqual(1, len(template['outputs']['artifacts']))
        self.assertFalse('parameters' in template['outputs'])

    def test_container_op_to_workflow_template(self):
        echo_task = dsl.ContainerOp(
            name='echo',
            image='library/bash:4.4.23',
            command=['sh', '-c'],
            arguments=['echo "hello world"']
        )

        template = containerOp_to_template(echo_task)
        self.assertEqual('echo', template['name'])
        self.assertEqual('library/bash:4.4.23', template['container']['image'])
        self.assertEqual(['sh', '-c'], template['container']['command'])
        self.assertEqual(['echo "hello world"'], template['container']['args'])



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.workflow.configuration import Configuration


class CodegenRun(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'run_id': 'str',
        'name': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'node': 'str',
        'pipeline_id': 'str',
        'properties': 'dict(str, str)',
        'status': 'str'
    }

    attribute_map = {
        'run_id': 'runId',
        'name': 'name',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'node': 'node',
        'pipeline_id': 'pipelineId',
        'properties': 'properties',
        'status': 'status'
    }

    def __init__(self, run_id=None, name=None, start_time=None, end_time=None, node=None, pipeline_id=None, properties=None, status=None, local_vars_configuration=None):  # noqa: E501
        """CodegenRun - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._run_id = None
        self._name = None
        self._start_time = None
        self._end_time = None
        self._node = None
        self._pipeline_id = None
        self._properties = None
        self._status = None
        self.discriminator = None

        if run_id is not None:
            self.run_id = run_id
        if name is not None:
            self.name = name
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if node is not None:
            self.node = node
        if pipeline_id is not None:
            self.pipeline_id = pipeline_id
        if properties is not None:
            self.properties = properties
        if status is not None:
            self.status = status

    @property
    def run_id(self):
        """Gets the run_id of this CodegenRun.  # noqa: E501


        :return: The run_id of this CodegenRun.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this CodegenRun.


        :param run_id: The run_id of this CodegenRun.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    @property
    def name(self):
        """Gets the name of this CodegenRun.  # noqa: E501


        :return: The name of this CodegenRun.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CodegenRun.


        :param name: The name of this CodegenRun.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def start_time(self):
        """Gets the start_time of this CodegenRun.  # noqa: E501


        :return: The start_time of this CodegenRun.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this CodegenRun.


        :param start_time: The start_time of this CodegenRun.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this CodegenRun.  # noqa: E501


        :return: The end_time of this CodegenRun.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this CodegenRun.


        :param end_time: The end_time of this CodegenRun.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def node(self):
        """Gets the node of this CodegenRun.  # noqa: E501


        :return: The node of this CodegenRun.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this CodegenRun.


        :param node: The node of this CodegenRun.  # noqa: E501
        :type: str
        """

        self._node = node

    @property
    def pipeline_id(self):
        """Gets the pipeline_id of this CodegenRun.  # noqa: E501


        :return: The pipeline_id of this CodegenRun.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_id

    @pipeline_id.setter
    def pipeline_id(self, pipeline_id):
        """Sets the pipeline_id of this CodegenRun.


        :param pipeline_id: The pipeline_id of this CodegenRun.  # noqa: E501
        :type: str
        """

        self._pipeline_id = pipeline_id

    @property
    def properties(self):
        """Gets the properties of this CodegenRun.  # noqa: E501


        :return: The properties of this CodegenRun.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CodegenRun.


        :param properties: The properties of this CodegenRun.  # noqa: E501
        :type: dict(str, str)
        """

        self._properties = properties

    @property
    def status(self):
        """Gets the status of this CodegenRun.  # noqa: E501


        :return: The status of this CodegenRun.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CodegenRun.


        :param status: The status of this CodegenRun.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenRun):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenRun):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kaistack.clients.openapi_clients.pipelinecomponents.api_client import ApiClient
from kaistack.clients.openapi_clients.pipelinecomponents.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PipelineComponentServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_component(self, body, **kwargs):  # noqa: E501
        """create_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_component(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenPipelineComponent body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenCreateComponentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_component_with_http_info(body, **kwargs)  # noqa: E501

    def create_component_with_http_info(self, body, **kwargs):  # noqa: E501
        """create_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_component_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenPipelineComponent body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenCreateComponentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenCreateComponentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_component(self, id, **kwargs):  # noqa: E501
        """delete_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_component(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenDeleteComponentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_component_with_http_info(id, **kwargs)  # noqa: E501

    def delete_component_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_component_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenDeleteComponentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `delete_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenDeleteComponentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_component(self, id, **kwargs):  # noqa: E501
        """get_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetComponentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_component_with_http_info(id, **kwargs)  # noqa: E501

    def get_component_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetComponentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetComponentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_component_by_name(self, name, **kwargs):  # noqa: E501
        """get_component_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str version:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenGetComponentByNameResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_component_by_name_with_http_info(name, **kwargs)  # noqa: E501

    def get_component_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """get_component_by_name  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_component_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str name: (required)
        :param str version:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenGetComponentByNameResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'name',
            'version'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_component_by_name" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'name' is set
        if self.api_client.client_side_validation and ('name' not in local_var_params or  # noqa: E501
                                                        local_var_params['name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `name` when calling `get_component_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in local_var_params:
            path_params['name'] = local_var_params['name']  # noqa: E501

        query_params = []
        if 'version' in local_var_params and local_var_params['version'] is not None:  # noqa: E501
            query_params.append(('version', local_var_params['version']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components/name/{name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenGetComponentByNameResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_component_versions(self, id, **kwargs):  # noqa: E501
        """list_component_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_component_versions(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenListComponentVersionsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_component_versions_with_http_info(id, **kwargs)  # noqa: E501

    def list_component_versions_with_http_info(self, id, **kwargs):  # noqa: E501
        """list_component_versions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_component_versions_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenListComponentVersionsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_component_versions" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `list_component_versions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components/versions/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenListComponentVersionsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_components(self, **kwargs):  # noqa: E501
        """list_components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_components(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenListComponentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_components_with_http_info(**kwargs)  # noqa: E501

    def list_components_with_http_info(self, **kwargs):  # noqa: E501
        """list_components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_components_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenListComponentsResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_components" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenListComponentsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_component(self, body, **kwargs):  # noqa: E501
        """update_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_component(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenPipelineComponent body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CodegenUpdateComponentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_component_with_http_info(body, **kwargs)  # noqa: E501

    def update_component_with_http_info(self, body, **kwargs):  # noqa: E501
        """update_component  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_component_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CodegenPipelineComponent body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CodegenUpdateComponentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_component" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `update_component`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/pipeline/components', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CodegenUpdateComponentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# Compile and convert kubeflow component
import base64
import re

from kfp.compiler._op_to_template import _op_to_template
from kfp.components import load_component_from_file
from kfp.dsl import PipelineParam, ContainerOp
from kfp.dsl._component_bridge import _create_container_op_from_component_and_arguments

valid_name_regex = r'^[A-Za-z][A-Za-z0-9_-]*$'


# KFP compile code will generate redudant parameter due to its original design
# In KFP's _data_passing_rewriter.py, it checks and fix. The function below did
# similar thing but with a different rule. It removes the redudant outputs parameter
def fix_parameter(template):
    """Fix the incorrect parameter generated by kfp compile"""
    if 'outputs' in template:
        parameters = template['outputs'].get('parameters')
        artifacts = template['outputs'].get('artifacts')
        if parameters is not None:
            temp = []
            for p in parameters:
                if artifacts is None or len(list(filter(lambda x: x.get('name') == p.get('name'), artifacts))) == 0:
                    temp.append(p)
            if len(temp) == 0:
                del template['outputs']['parameters']
            else:
                template['outputs']['parameters'] = temp
    return template


def validTemplateName(name: str):
    """Validate if the template name is compliant to the requirement"""
    return re.match(valid_name_regex, name)


def encode_k8s_name(input: str) -> str:
    """Encode name to be compatible with Kubernetes name convention"""
    return base64.b32encode(input.encode('utf-8')).decode('utf-8').lower().rstrip('=')


def restore_human_names(container_op: ContainerOp):
    """Remove the hash in the name"""
    container_op.name = container_op.human_name if validTemplateName(container_op.human_name) else encode_k8s_name(
        container_op.human_name)
    if container_op.output:
        container_op.output = PipelineParam(name=container_op.output.name, value=container_op.output.value)

    for k, v in container_op.outputs.items():
        container_op.outputs[k] = PipelineParam(name=container_op.output.name, value=container_op.output.value)


def component_to_template(file_name: str):
    """Convert to a component to an argo template"""
    component = load_component_from_file(file_name).component_spec
    args = {}
    for input in component.inputs:
        args[input.name] = PipelineParam(name=input.name, value="{{inputs.parameters." + input.name + "}}")
    container_op = _create_container_op_from_component_and_arguments(component, args)
    # Component to op process creating some hash name for tasks. Restore them here
    restore_human_names(container_op)
    return fix_parameter(_op_to_template(container_op))


def containerOp_to_template(op: ContainerOp):
    """Convert a container op to an argo template"""
    template = _op_to_template(op)
    template['name'] = op.human_name if validTemplateName(op.human_name) else encode_k8s_name(op.human_name)
    return fix_parameter(template)


def create_workflow_template_from_component_spec(file_name: str):
    """Create an argo workflowtemplate object from the given kfp component"""
    template = component_to_template(file_name)
    workflow_template = {
        'apiVersion': 'argoproj.io/v1alpha1',
        'kind': 'WorkflowTemplate',
        'metadata': {
            'name': encode_k8s_name(template['name']),
        },
        'spec': {
            'templates': [
                template
            ]
        }
    }
    return workflow_template


def create_workflow_template_from_container_op(op: ContainerOp):
    """Create an argo workflowtemplate object from a defined ContainerOp"""
    template = containerOp_to_template(op)
    workflow_template = {
        'apiVersion': 'argoproj.io/v1alpha1',
        'kind': 'WorkflowTemplate',
        'metadata': {
            'name': encode_k8s_name(template['name']),
        },
        'spec': {
            'templates': [
                template
            ]
        }
    }
    return workflow_template



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kaistack.clients.openapi_clients.pipelinecomponents.api.pipeline_component_service_api import PipelineComponentServiceApi



# coding: utf-8

# flake8: noqa

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from kaistack.clients.openapi_clients.cluster.api.cluster_service_api import ClusterServiceApi

# import ApiClient
from kaistack.clients.openapi_clients.cluster.api_client import ApiClient
from kaistack.clients.openapi_clients.cluster.configuration import Configuration
from kaistack.clients.openapi_clients.cluster.exceptions import OpenApiException
from kaistack.clients.openapi_clients.cluster.exceptions import ApiTypeError
from kaistack.clients.openapi_clients.cluster.exceptions import ApiValueError
from kaistack.clients.openapi_clients.cluster.exceptions import ApiKeyError
from kaistack.clients.openapi_clients.cluster.exceptions import ApiException
# import models into sdk package
from kaistack.clients.openapi_clients.cluster.models.codegen_artifacts_store_config import CodegenArtifactsStoreConfig
from kaistack.clients.openapi_clients.cluster.models.codegen_cluster_config import CodegenClusterConfig
from kaistack.clients.openapi_clients.cluster.models.codegen_get_cluster_config_response import CodegenGetClusterConfigResponse
from kaistack.clients.openapi_clients.cluster.models.codegen_get_nodes_response import CodegenGetNodesResponse
from kaistack.clients.openapi_clients.cluster.models.codegen_get_system_status_response import CodegenGetSystemStatusResponse
from kaistack.clients.openapi_clients.cluster.models.codegen_node import CodegenNode
from kaistack.clients.openapi_clients.cluster.models.codegen_system_component_deployment import CodegenSystemComponentDeployment
from kaistack.clients.openapi_clients.cluster.models.codegen_system_status import CodegenSystemStatus




# coding: utf-8

"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.pipelinecomponents
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_by_name_response import CodegenGetComponentByNameResponse  # noqa: E501
from kaistack.clients.openapi_clients.pipelinecomponents.rest import ApiException

class TestCodegenGetComponentByNameResponse(unittest.TestCase):
    """CodegenGetComponentByNameResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetComponentByNameResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_by_name_response.CodegenGetComponentByNameResponse()  # noqa: E501
        if include_optional :
            return CodegenGetComponentByNameResponse(
                component = kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_pipeline_component.codegenPipelineComponent(
                    id = '0', 
                    name = '0', 
                    description = '0', 
                    image = '0', 
                    creator = '0', 
                    version = '0', 
                    help_link = '0', 
                    spec = '0', 
                    sha256 = '0', 
                    created_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                error = '0'
            )
        else :
            return CodegenGetComponentByNameResponse(
        )

    def testCodegenGetComponentByNameResponse(self):
        """Test CodegenGetComponentByNameResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from setuptools import setup
from setuptools import find_packages


NAME = 'kaistack'
__version__ = '0.1.3'

REQUIRES = [
    'kfp>=0.5.1'
    'certifi==2019.11.28'
    'auth0-python==3.9.1'
    'Click>=7.0'
]


setup(
    name=NAME,
    version=__version__,
    description='Hypertensor Kaistack SDK',
    author='HypertensorAI',
    install_requires=REQUIRES,
    license='apache-2.0',
    packages=find_packages(include=['kaistack*']),
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.5.3',
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'kaistack=kaistack.cli.cli:main',
            'run_notebook=kaistack.tools.run_notebook:main',
        ]
    })



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.workflow.configuration import Configuration


class CodegenGetArtifactsFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'experiment': 'str',
        'pipeline_run_id': 'str',
        'run_id': 'str'
    }

    attribute_map = {
        'experiment': 'experiment',
        'pipeline_run_id': 'pipelineRunId',
        'run_id': 'runId'
    }

    def __init__(self, experiment=None, pipeline_run_id=None, run_id=None, local_vars_configuration=None):  # noqa: E501
        """CodegenGetArtifactsFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._experiment = None
        self._pipeline_run_id = None
        self._run_id = None
        self.discriminator = None

        if experiment is not None:
            self.experiment = experiment
        if pipeline_run_id is not None:
            self.pipeline_run_id = pipeline_run_id
        if run_id is not None:
            self.run_id = run_id

    @property
    def experiment(self):
        """Gets the experiment of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The experiment of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._experiment

    @experiment.setter
    def experiment(self, experiment):
        """Sets the experiment of this CodegenGetArtifactsFilter.


        :param experiment: The experiment of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._experiment = experiment

    @property
    def pipeline_run_id(self):
        """Gets the pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_run_id

    @pipeline_run_id.setter
    def pipeline_run_id(self, pipeline_run_id):
        """Sets the pipeline_run_id of this CodegenGetArtifactsFilter.


        :param pipeline_run_id: The pipeline_run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._pipeline_run_id = pipeline_run_id

    @property
    def run_id(self):
        """Gets the run_id of this CodegenGetArtifactsFilter.  # noqa: E501


        :return: The run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :rtype: str
        """
        return self._run_id

    @run_id.setter
    def run_id(self, run_id):
        """Sets the run_id of this CodegenGetArtifactsFilter.


        :param run_id: The run_id of this CodegenGetArtifactsFilter.  # noqa: E501
        :type: str
        """

        self._run_id = run_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenGetArtifactsFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenGetArtifactsFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import kaistack.clients.openapi_clients.workflow
from kaistack.clients.openapi_clients.workflow.models.codegen_get_argo_workflow_response import CodegenGetArgoWorkflowResponse  # noqa: E501
from kaistack.clients.openapi_clients.workflow.rest import ApiException

class TestCodegenGetArgoWorkflowResponse(unittest.TestCase):
    """CodegenGetArgoWorkflowResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CodegenGetArgoWorkflowResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kaistack.clients.openapi_clients.workflow.models.codegen_get_argo_workflow_response.CodegenGetArgoWorkflowResponse()  # noqa: E501
        if include_optional :
            return CodegenGetArgoWorkflowResponse(
                workflow = kaistack.clients.openapi_clients.workflow.models.codegen_argo_workflow.codegenArgoWorkflow(
                    name = '0', )
            )
        else :
            return CodegenGetArgoWorkflowResponse(
        )

    def testCodegenGetArgoWorkflowResponse(self):
        """Test CodegenGetArgoWorkflowResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    pipelinecomponentapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_create_component_response import CodegenCreateComponentResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_delete_component_response import CodegenDeleteComponentResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_by_name_response import CodegenGetComponentByNameResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_get_component_response import CodegenGetComponentResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_list_component_versions_response import CodegenListComponentVersionsResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_list_components_response import CodegenListComponentsResponse
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_pipeline_component import CodegenPipelineComponent
from kaistack.clients.openapi_clients.pipelinecomponents.models.codegen_update_component_response import CodegenUpdateComponentResponse
